@@ -22,7 +22,8 @@ G_DECLARE_FINAL_TYPE (PhoshNotificationContent, phosh_notification_content, PHOS
 
 
 GtkWidget         *phosh_notification_content_new              (PhoshNotification        *notification,
-                                                                gboolean                  show_body);
+                                                                gboolean                  show_body,
+                                                                const char * const       *action_filters);
 PhoshNotification *phosh_notification_content_get_notification (PhoshNotificationContent *self);
 
 
