@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2018 Purism SPC
- *               2023-2024 The Phosh Developers
+ *               2023-2025 The Phosh Developers
  *
  * SPDX-License-Identifier: GPL-3.0-or-later
  *
@@ -55,7 +55,7 @@
 #include "layout-manager.h"
 #include "location-manager.h"
 #include "lockscreen-manager-priv.h"
-#include "media-player.h"
+#include "default-media-player.h"
 #include "mode-manager.h"
 #include "monitor-manager.h"
 #include "monitor/monitor.h"
@@ -64,6 +64,7 @@
 #include "revealer.h"
 #include "settings.h"
 #include "system-modal-dialog.h"
+#include "mpris-manager.h"
 #include "network-auth-manager.h"
 #include "notifications/notify-manager.h"
 #include "notifications/notification-banner.h"
@@ -184,6 +185,7 @@ typedef struct
   PhoshLauncherEntryManager *launcher_entry_manager;
   PhoshCellBroadcastManager *cell_broadcast_manager;
   PhoshConnectivityManager *connectivity_manager;
+  PhoshMprisManager *mpris_manager;
 
   /* sensors */
   PhoshSensorProxyManager *sensor_proxy_manager;
@@ -542,9 +544,10 @@ phosh_shell_dispose (GObject *object)
   panels_dispose (self);
   g_clear_pointer (&priv->faders, g_ptr_array_unref);
 
-  g_clear_object (&priv->notification_banner);
+  g_clear_pointer (&priv->notification_banner, phosh_cp_widget_destroy);
 
   /* dispose managers in opposite order of declaration */
+  g_clear_object (&priv->mpris_manager);
   g_clear_object (&priv->connectivity_manager);
   g_clear_object (&priv->cell_broadcast_manager);
   g_clear_object (&priv->launcher_entry_manager);
@@ -652,15 +655,15 @@ on_new_notification (PhoshShell         *self,
   priv = phosh_shell_get_instance_private (self);
 
   /* Clear existing banner */
-  if (priv->notification_banner && GTK_IS_WIDGET (priv->notification_banner)) {
-    gtk_widget_destroy (priv->notification_banner);
-  }
-
+  g_clear_pointer (&priv->notification_banner, phosh_cp_widget_destroy);
   if (phosh_notify_manager_get_show_notification_banner (manager, notification) &&
       phosh_top_panel_get_state (PHOSH_TOP_PANEL (priv->top_panel)) == PHOSH_TOP_PANEL_STATE_FOLDED &&
       !priv->locked) {
-    g_set_weak_pointer (&priv->notification_banner,
-                        phosh_notification_banner_new (notification));
+    priv->notification_banner = phosh_notification_banner_new (notification);
+    g_signal_connect (priv->notification_banner,
+                      "destroy",
+                      G_CALLBACK (gtk_widget_destroyed),
+                      &priv->notification_banner);
 
     gtk_widget_set_visible (GTK_WIDGET (priv->notification_banner), TRUE);
   }
@@ -844,7 +847,7 @@ type_setup (void)
   g_type_ensure (PHOSH_TYPE_FEEDBACK_INFO);
   g_type_ensure (PHOSH_TYPE_HKS_INFO);
   g_type_ensure (PHOSH_TYPE_LOCATION_INFO);
-  g_type_ensure (PHOSH_TYPE_MEDIA_PLAYER);
+  g_type_ensure (PHOSH_TYPE_DEFAULT_MEDIA_PLAYER);
   g_type_ensure (PHOSH_TYPE_PASSWORD_ENTRY);
   g_type_ensure (PHOSH_TYPE_QUICK_SETTING);
   g_type_ensure (PHOSH_TYPE_REVEALER);
@@ -1934,6 +1937,29 @@ phosh_shell_get_location_manager (PhoshShell *self)
   return priv->location_manager;
 }
 
+/**
+ * phosh_shell_get_mpris_manager:
+ * @self: The shell singleton
+ *
+ * Get the MPRIS manager
+ *
+ * Returns: (transfer none): The MPRIS manager
+ */
+PhoshMprisManager *
+phosh_shell_get_mpris_manager (PhoshShell *self)
+{
+  PhoshShellPrivate *priv;
+
+  g_return_val_if_fail (PHOSH_IS_SHELL (self), NULL);
+  priv = phosh_shell_get_instance_private (self);
+
+  if (!priv->mpris_manager)
+    priv->mpris_manager = phosh_mpris_manager_new ();
+
+  g_return_val_if_fail (PHOSH_IS_MPRIS_MANAGER (priv->mpris_manager), NULL);
+  return priv->mpris_manager;
+}
+
 /**
  * phosh_shell_get_osk_manager:
  * @self: The shell singleton
